==> minitube-0.8.1.tar.gz: minitube/locale/fr_FR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Il y a une vie après le browser !</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Version %1</translation>
    </message>
    <message>
        <source>This is a &quot;Technology Preview&quot; release, do not expect it to be perfect.</source>
        <translation>Ceci est une &quot;Preview Technologique&quot;, ne vous attendez pas à ce que ce soit parfait.</translation>
    </message>
    <message>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>Rapportez les bugs et envoyez vos idées à %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 est un Logiciel Libre, mais son développement prend un temps précieux.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate via PayPal&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Merci &lt;a href=&apos;%1&apos;&gt;d&apos;envoyer vos dons via PayPal&lt;/a&gt; pour aider à poursuivre le développement de %2.</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Icône déssinée par %1.</translation>
    </message>
    <message>
        <source>Compact mode contributed by %1.</source>
        <translation>Mode compact développé par %1.</translation>
    </message>
    <message>
        <source>HTTP proxy support contributed by %1.</source>
        <translation>Support du proxy HTTP apporté par %1.</translation>
    </message>
    <message>
        <source>Windows version built by %1</source>
        <translation>Version Windows faite par %1</translation>
    </message>
    <message>
        <source>Translated by %1</source>
        <translation>Traduction par %1</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Proposé sous licence &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fermer</translation>
    </message>
    <message>
        <source>About</source>
        <translation>A propos</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Ce que vous avez toujours voulu savoir à propos de %1 et que vous n&apos;avez jamais osé le demander</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Effacer</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <source>Searching...</source>
        <translation>Recherche...</translation>
    </message>
    <message>
        <source>Show %1 More</source>
        <translation>Afficher %1 de plus</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Pas de vidéos</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Plus de vidéos</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Retour</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>Aller à la vue précédente</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Stop</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Arrêter et aller à la page de recherche</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>&amp;Sauter</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Passer à la vidéo suivante</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Mettre en pause</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Plein écran</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Mettre en plein écran</translation>
    </message>
    <message>
        <source>&amp;Compact mode</source>
        <translation>Mode &amp;compact</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Cacher la playlist</translation>
    </message>
    <message>
        <source>&amp;YouTube</source>
        <translation>&amp;Youtube</translation>
    </message>
    <message>
        <source>Open the YouTube video page</source>
        <translation>Ouvrir la page Youtube</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Supprimer</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Supprimer la vidéo sélectionnée de la liste de lecture</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Déplacer vers les &amp;haut</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Déplacer la vidéo sélectionnée vers le haut dans la liste de lecture</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Déplacer vers les &amp;bas</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Déplacer la vidéo sélectionnée vers le bas dans la liste de lecture</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Au revoir</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>Site &amp;Web</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 sur le Web</translation>
    </message>
    <message>
        <source>&amp;Donate via PayPal</source>
        <translation>Faire un &amp;don via PayPal</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Merci d&apos;aider à poursuivre le développement de %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;A propos</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>A propos de %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Chercher</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Couper le son</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Liste de lecture</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Appuyer sur %1 pour augmenter le volume, sur %2 pour le baisser</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Ouverture de %1</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Erreur fatale : %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Erreur : %1</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Jouer</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Relancer la lecture</translation>
    </message>
    <message>
        <source>Exit &amp;Full Screen</source>
        <translation>Quitter le &amp;plein écran</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Temps restant : %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Volume à %1</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Volume OFF</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Volume ON</translation>
    </message>
    <message>
        <source>High Definition video is enabled</source>
        <translation>Haute définition activée</translation>
    </message>
    <message>
        <source>High Definition video is not enabled</source>
        <translation>Haute définition désactivée</translation>
    </message>
    <message>
        <source>The current video is in High Definition</source>
        <translation>La vidéo actuelle est en Haute Définition</translation>
    </message>
    <message>
        <source>The current video is not in High Definition</source>
        <translation>La vidéo actuelle n&apos;est pas en Haute Définition</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Most relevant</source>
        <translation>Plus pertinent</translation>
    </message>
    <message>
        <source>Most recent</source>
        <translation>Plus récent</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>Plus vus</translation>
    </message>
    <message>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation>Vous regardez %1</translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <source>Network error: %1</source>
        <translation>Erreur réseau : %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <source>%1 views</source>
        <translation>%1 vues</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Chercher</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Bienvenue sur  &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>Enter a keyword to start watching videos.</source>
        <translation>Entre un mot-clé pour commencer à regarder des vidéos.</translation>
    </message>
    <message>
        <source>Watch</source>
        <translation>Regarder</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Derniers mots-clés</translation>
    </message>
    <message>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>Une nouvelle version de %1 est disponible. Merci &lt;a href=&apos;%2&apos;&gt;de mettre à jour pour la version %3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Installez-vous confortablement</translation>
    </message>
</context>
<context>
    <name>SettingsView</name>
    <message>
        <source>Preferences</source>
        <translation>Préférences</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <source>Network error: %1 for %2</source>
        <translation>Erreur réseau : %1 pour %2</translation>
    </message>
</context>
</TS>

==> minitube-0.9.tar.gz: minitube/locale/fr_FR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Il y a une vie après le browser !</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Version %1</translation>
    </message>
    <message>
        <source>This is a &quot;Technology Preview&quot; release, do not expect it to be perfect.</source>
        <translation>Ceci est une &quot;Preview Technologique&quot;, ne vous attendez pas à ce que ce soit parfait.</translation>
    </message>
    <message>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>Rapportez les bugs et envoyez vos idées à %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 est un Logiciel Libre, mais son développement prend un temps précieux.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate via PayPal&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Merci &lt;a href=&apos;%1&apos;&gt;d&apos;envoyer vos dons via PayPal&lt;/a&gt; pour aider à poursuivre le développement de %2.</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Icône déssinée par %1.</translation>
    </message>
    <message>
        <source>Compact mode contributed by %1.</source>
        <translation>Mode compact développé par %1.</translation>
    </message>
    <message>
        <source>HTTP proxy support contributed by %1.</source>
        <translation>Support du proxy HTTP apporté par %1.</translation>
    </message>
    <message>
        <source>Windows version built by %1</source>
        <translation type="obsolete">Version Windows faite par %1</translation>
    </message>
    <message>
        <source>Translated by %1</source>
        <translation>Traduction par %1</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Proposé sous licence &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fermer</translation>
    </message>
    <message>
        <source>About</source>
        <translation>A propos</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Ce que vous avez toujours voulu savoir à propos de %1 et que vous n&apos;avez jamais osé le demander</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Effacer</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <source>Searching...</source>
        <translation>Recherche...</translation>
    </message>
    <message>
        <source>Show %1 More</source>
        <translation>Afficher %1 de plus</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Pas de vidéos</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Plus de vidéos</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Retour</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>Aller à la vue précédente</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Stop</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Arrêter et aller à la page de recherche</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>&amp;Sauter</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Passer à la vidéo suivante</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Mettre en pause</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Plein écran</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Mettre en plein écran</translation>
    </message>
    <message>
        <source>&amp;Compact mode</source>
        <translation>Mode &amp;compact</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Cacher la playlist</translation>
    </message>
    <message>
        <source>&amp;YouTube</source>
        <translation>&amp;Youtube</translation>
    </message>
    <message>
        <source>Open the YouTube video page</source>
        <translation>Ouvrir la page Youtube</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Supprimer</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Supprimer la vidéo sélectionnée de la liste de lecture</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Déplacer vers les &amp;haut</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Déplacer la vidéo sélectionnée vers le haut dans la liste de lecture</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Déplacer vers les &amp;bas</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Déplacer la vidéo sélectionnée vers le bas dans la liste de lecture</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Au revoir</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>Site &amp;Web</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 sur le Web</translation>
    </message>
    <message>
        <source>&amp;Donate via PayPal</source>
        <translation>Faire un &amp;don via PayPal</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Merci d&apos;aider à poursuivre le développement de %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;A propos</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>A propos de %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Chercher</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Couper le son</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Liste de lecture</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Appuyer sur %1 pour augmenter le volume, sur %2 pour le baisser</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Ouverture de %1</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Erreur fatale : %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Erreur : %1</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Jouer</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Relancer la lecture</translation>
    </message>
    <message>
        <source>Exit &amp;Full Screen</source>
        <translation>Quitter le &amp;plein écran</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Temps restant : %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Volume à %1</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Volume OFF</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Volume ON</translation>
    </message>
    <message>
        <source>High Definition video is enabled</source>
        <translation>Haute définition activée</translation>
    </message>
    <message>
        <source>High Definition video is not enabled</source>
        <translation>Haute définition désactivée</translation>
    </message>
    <message>
        <source>The current video is in High Definition</source>
        <translation>La vidéo actuelle est en Haute Définition</translation>
    </message>
    <message>
        <source>The current video is not in High Definition</source>
        <translation>La vidéo actuelle n&apos;est pas en Haute Définition</translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Most relevant</source>
        <translation>Plus pertinent</translation>
    </message>
    <message>
        <source>Most recent</source>
        <translation>Plus récent</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>Plus vus</translation>
    </message>
    <message>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation>Vous regardez %1</translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <source>Network error: %1</source>
        <translation>Erreur réseau : %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <source>%1 views</source>
        <translation>%1 vues</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Chercher</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Bienvenue sur  &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>Enter a keyword to start watching videos.</source>
        <translation>Entre un mot-clé pour commencer à regarder des vidéos.</translation>
    </message>
    <message>
        <source>Watch</source>
        <translation>Regarder</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Derniers mots-clés</translation>
    </message>
    <message>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>Une nouvelle version de %1 est disponible. Merci &lt;a href=&apos;%2&apos;&gt;de mettre à jour pour la version %3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Installez-vous confortablement</translation>
    </message>
</context>
<context>
    <name>SettingsView</name>
    <message>
        <source>Preferences</source>
        <translation>Préférences</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <source>Network error: %1 for %2</source>
        <translation>Erreur réseau : %1 pour %2</translation>
    </message>
</context>
</TS>
